@@ -92,6 +92,11 @@ class ClDesktopAction(Action):
           'condition':lambda Get: Get('cl_desktop_force_setup_set') == 'on' or \
                              Get('cl_desktop_update_profile_set') == 'on'
          },
+         {'name':'fast_login',
+          'method':'Desktop.setFastlogin(ur_login)',
+          'essential':False,
+          'condition':lambda Get: Get('ur_domain_set') == 'off'
+         },
          # отключить ресурсы подключенные в каталоге пользователя
          {'name':'umount_userres',
           'message': _("Unmouning user resources"),
